@@ -158,7 +158,7 @@ class Ui_MainWindow(object):
         self.override.addItem("")
         self.override.addItem("")
         self.override.addItem("")
-        self.override.setItemText(2, "")
+        self.override.setItemText(3, "")
         self.horizontalLayout.addWidget(self.override)
         self.medpctoexcel_progressbar = QtWidgets.QProgressBar(self.SessionAnalysis)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
@@ -263,8 +263,9 @@ class Ui_MainWindow(object):
         MainWindow.setWindowTitle(_translate("MainWindow", "Behavior Data Extracter"))
         self.datafolder_button.setText(_translate("MainWindow", "Data folder"))
         self.medpctoexcel_button.setText(_translate("MainWindow", "MED-PC to Excel"))
-        self.override.setItemText(0, _translate("MainWindow", "Override existing data"))
-        self.override.setItemText(1, _translate("MainWindow", "Skip existing data"))
+        self.override.setItemText(0, _translate("MainWindow", "Override"))
+        self.override.setItemText(1, _translate("MainWindow", "Replace"))
+        self.override.setItemText(2, _translate("MainWindow", "Append"))
         self.medpctoexcel_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.load_configfile_button.setText(_translate("MainWindow", "Load Config.xlsm file"))
         self.genTSfile_button.setText(_translate("MainWindow", "Generate TS file"))
@@ -272,7 +273,7 @@ class Ui_MainWindow(object):
         self.genVar_button.setText(_translate("MainWindow", "Generate Variables"))
         self.genVar_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tab_GenVar.setTabText(self.tab_GenVar.indexOf(self.SessionAnalysis), _translate("MainWindow", "Generate Variables"))
-        self.label_18.setText(_translate("MainWindow", "Current version v1.6.0 \n"
+        self.label_18.setText(_translate("MainWindow", "Current version v1.7.1 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -324,16 +325,21 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         datafile_list = files.get_dir_list(display=False)
         self.log.append (self.currentTime+'>>\t'+'Found %s files'%(len(datafile_list)))
         override = str(self.override.currentText()) 
-        if override == 'Override existing data':
-            replace = True
-        else:
-            replace = False
+        if override == 'Override':
+            replace_file = True
+            replace_data  = True
+        elif override == 'Replace':
+            replace_file = False
+            replace_data = True
+        elif override == 'Append':
+            replace_file = False
+            replace_data = False
         
         total = len(datafile_list)
         func_out = ''
         for n, f in enumerate(datafile_list):
             #get all data from this session
-            _, func_out = medpc_read(f, replace = replace, log = func_out) #pass TS_df_tree to an anonymous variable
+            _, func_out = medpc_read(f, override = replace_file, replace = replace_data, log = func_out) #pass TS_df_tree to an anonymous variable
             self.medpctoexcel_progressbar.setValue(n/total*100)
         self.medpctoexcel_progressbar.setValue(100)
         self.log.append(func_out)
